@@ -32,19 +32,20 @@ public:
 
 private Q_SLOTS:
     void testReloadMultipleViews();
+    void testTabCursorOnReload();
 
     void testLowerCaseBlockSelection();
 
-    void testFolding_data();
-    void testFolding();
-
     void testCoordinatesToCursor();
     void testCursorToCoordinates();
 
-    void testBug287291();
-
     void testSelection();
     void testKillline();
+    void testScrollPastEndOfDocument();
+
+    void testFoldFirstLine();
+
+    void testDragAndDrop();
 };
 
 #endif // KATE_VIEW_TEST_H
