@@ -52,7 +52,7 @@ KateBuffer::KateBuffer(KTextEditor::DocumentPrivate *doc)
       m_brokenEncoding(false),
       m_tooLongLinesWrapped(false),
       m_longestLineLoaded(0),
-      m_highlight(0),
+      m_highlight(nullptr),
       m_tabWidth(8),
       m_lineHighlighted(0),
       m_maxDynamicContexts(KATE_MAX_DYNAMIC_CONTEXTS)
@@ -64,10 +64,6 @@ KateBuffer::KateBuffer(KTextEditor::DocumentPrivate *doc)
  */
 KateBuffer::~KateBuffer()
 {
-    // release HL
-    if (m_highlight) {
-        m_highlight->release();
-    }
 }
 
 void KateBuffer::editStart()
@@ -117,15 +113,16 @@ void KateBuffer::editEnd()
     /**
      * look one line too far, needed for linecontinue stuff
      */
-    int editTagLineEnd = editingMaximalLineChanged() + 1;
-    int editTagLineStart = editingMinimalLineChanged();
+    const int editTagLineEnd = editingMaximalLineChanged() + 1;
 
     /**
-     * look one line before, needed nearly 100% only for indentation based folding !
+     * for indentation sensitive folding, we need to redo things
+     * one line up, to e.g. get notified about new folding starts
+     * see bug 351496
      */
-    if (editTagLineStart > 0) {
+    int editTagLineStart = editingMinimalLineChanged();
+    if ((editTagLineStart > 0) && m_highlight->foldingIndentationSensitive())
         --editTagLineStart;
-    }
 
     /**
      * really update highlighting
@@ -228,17 +225,16 @@ bool KateBuffer::canEncode()
 {
     QTextCodec *codec = m_doc->config()->codec();
 
-    qCDebug(LOG_PART) << QLatin1String("ENC NAME: ") << codec->name();
-
-    // hardcode some unicode encodings which can encode all chars
+    // hardcode some Unicode encodings which can encode all chars
     if ((QString::fromLatin1(codec->name()) == QLatin1String("UTF-8")) || (QString::fromLatin1(codec->name()) == QLatin1String("ISO-10646-UCS-2"))) {
         return true;
     }
 
     for (int i = 0; i < lines(); i++) {
         if (!codec->canEncode(line(i)->string())) {
-            qCDebug(LOG_PART) << QLatin1String("STRING LINE: ") << line(i)->string();
-            qCDebug(LOG_PART) << QLatin1String("ENC WORKING: FALSE");
+            qCDebug(LOG_KTE) << QLatin1String("ENC NAME: ") << codec->name();
+            qCDebug(LOG_KTE) << QLatin1String("STRING LINE: ") << line(i)->string();
+            qCDebug(LOG_KTE) << QLatin1String("ENC WORKING: FALSE");
 
             return false;
         }
@@ -336,7 +332,6 @@ void KateBuffer::setHighlight(int hlMode)
         bool invalidate = !h->noHighlighting();
 
         if (m_highlight) {
-            m_highlight->release();
             invalidate = true;
         }
 
@@ -374,9 +369,9 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
 #ifdef BUFFER_DEBUGGING
     QTime t;
     t.start();
-    qCDebug(LOG_PART) << "HIGHLIGHTED START --- NEED HL, LINESTART: " << startLine << " LINEEND: " << endLine;
-    qCDebug(LOG_PART) << "HL UNTIL LINE: " << m_lineHighlighted;
-    qCDebug(LOG_PART) << "HL DYN COUNT: " << KateHlManager::self()->countDynamicCtxs() << " MAX: " << m_maxDynamicContexts;
+    qCDebug(LOG_KTE) << "HIGHLIGHTED START --- NEED HL, LINESTART: " << startLine << " LINEEND: " << endLine;
+    qCDebug(LOG_KTE) << "HL UNTIL LINE: " << m_lineHighlighted;
+    qCDebug(LOG_KTE) << "HL DYN COUNT: " << KateHlManager::self()->countDynamicCtxs() << " MAX: " << m_maxDynamicContexts;
 #endif
 
     // see if there are too many dynamic contexts; if yes, invalidate HL of all documents
@@ -384,7 +379,7 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
         {
             if (KateHlManager::self()->resetDynamicCtxs()) {
 #ifdef BUFFER_DEBUGGING
-                qCDebug(LOG_PART) << "HL invalidated - too many dynamic contexts ( >= " << m_maxDynamicContexts << ")";
+                qCDebug(LOG_KTE) << "HL invalidated - too many dynamic contexts ( >= " << m_maxDynamicContexts << ")";
 #endif
 
                 // avoid recursive invalidation
@@ -405,7 +400,7 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
                 m_maxDynamicContexts *= 2;
 
 #ifdef BUFFER_DEBUGGING
-                qCDebug(LOG_PART) << "New dynamic contexts limit: " << m_maxDynamicContexts;
+                qCDebug(LOG_KTE) << "New dynamic contexts limit: " << m_maxDynamicContexts;
 #endif
             }
         }
@@ -436,14 +431,14 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
 
 #ifdef BUFFER_DEBUGGING
         // debug stuff
-        qCDebug(LOG_PART) << "current line to hl: " << current_line;
-        qCDebug(LOG_PART) << "text length: " << textLine->length() << " attribute list size: " << textLine->attributesList().size();
+        qCDebug(LOG_KTE) << "current line to hl: " << current_line;
+        qCDebug(LOG_KTE) << "text length: " << textLine->length() << " attribute list size: " << textLine->attributesList().size();
 
         const QVector<int> &ml(textLine->attributesList());
         for (int i = 2; i < ml.size(); i += 3) {
-            qCDebug(LOG_PART) << "start: " << ml.at(i - 2) << " len: " << ml.at(i - 1) << " at: " << ml.at(i) << " ";
+            qCDebug(LOG_KTE) << "start: " << ml.at(i - 2) << " len: " << ml.at(i - 1) << " at: " << ml.at(i) << " ";
         }
-        qCDebug(LOG_PART);
+        qCDebug(LOG_KTE);
 #endif
 
         // need we to continue ?
@@ -470,7 +465,7 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
     // tag the changed lines !
     if (invalidate) {
 #ifdef BUFFER_DEBUGGING
-        qCDebug(LOG_PART) << "HIGHLIGHTED TAG LINES: " << startLine <<  current_line;
+        qCDebug(LOG_KTE) << "HIGHLIGHTED TAG LINES: " << startLine <<  current_line;
 #endif
 
         emit tagLines(startLine, qMax(current_line, oldHighlighted));
@@ -482,10 +477,10 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
     }
 
 #ifdef BUFFER_DEBUGGING
-    qCDebug(LOG_PART) << "HIGHLIGHTED END --- NEED HL, LINESTART: " << startLine << " LINEEND: " << endLine;
-    qCDebug(LOG_PART) << "HL UNTIL LINE: " << m_lineHighlighted;
-    qCDebug(LOG_PART) << "HL DYN COUNT: " << KateHlManager::self()->countDynamicCtxs() << " MAX: " << m_maxDynamicContexts;
-    qCDebug(LOG_PART) << "TIME TAKEN: " << t.elapsed();
+    qCDebug(LOG_KTE) << "HIGHLIGHTED END --- NEED HL, LINESTART: " << startLine << " LINEEND: " << endLine;
+    qCDebug(LOG_KTE) << "HL UNTIL LINE: " << m_lineHighlighted;
+    qCDebug(LOG_KTE) << "HL DYN COUNT: " << KateHlManager::self()->countDynamicCtxs() << " MAX: " << m_maxDynamicContexts;
+    qCDebug(LOG_KTE) << "TIME TAKEN: " << t.elapsed();
 #endif
 }
 
