@@ -76,10 +76,10 @@ void KateConfig::configEnd()
 //END
 
 //BEGIN KateDocumentConfig
-KateGlobalConfig *KateGlobalConfig::s_global = 0;
-KateDocumentConfig *KateDocumentConfig::s_global = 0;
-KateViewConfig *KateViewConfig::s_global = 0;
-KateRendererConfig *KateRendererConfig::s_global = 0;
+KateGlobalConfig *KateGlobalConfig::s_global = nullptr;
+KateDocumentConfig *KateDocumentConfig::s_global = nullptr;
+KateViewConfig *KateViewConfig::s_global = nullptr;
+KateRendererConfig *KateRendererConfig::s_global = nullptr;
 
 KateGlobalConfig::KateGlobalConfig()
 {
@@ -184,6 +184,7 @@ KateDocumentConfig::KateDocumentConfig()
       m_smartHomeSet(false),
       m_showTabsSet(false),
       m_showSpacesSet(false),
+      m_markerSize(1),
       m_replaceTabsDynSet(false),
       m_removeSpacesSet(false),
       m_newLineAtEofSet(false),
@@ -201,7 +202,7 @@ KateDocumentConfig::KateDocumentConfig()
       m_swapSyncIntervalSet(false),
       m_onTheFlySpellCheckSet(false),
       m_lineLengthLimitSet(false),
-      m_doc(0)
+      m_doc(nullptr)
 {
     s_global = this;
 
@@ -228,6 +229,7 @@ KateDocumentConfig::KateDocumentConfig(const KConfigGroup &cg)
       m_smartHomeSet(false),
       m_showTabsSet(false),
       m_showSpacesSet(false),
+      m_markerSize(1),
       m_replaceTabsDynSet(false),
       m_removeSpacesSet(false),
       m_newLineAtEofSet(false),
@@ -245,7 +247,7 @@ KateDocumentConfig::KateDocumentConfig(const KConfigGroup &cg)
       m_swapSyncIntervalSet(false),
       m_onTheFlySpellCheckSet(false),
       m_lineLengthLimitSet(false),
-      m_doc(0)
+      m_doc(nullptr)
 {
     // init with defaults from config or really hardcoded ones
     readConfig(cg);
@@ -266,6 +268,7 @@ KateDocumentConfig::KateDocumentConfig(KTextEditor::DocumentPrivate *doc)
       m_smartHomeSet(false),
       m_showTabsSet(false),
       m_showSpacesSet(false),
+      m_markerSize(1),
       m_replaceTabsDynSet(false),
       m_removeSpacesSet(false),
       m_newLineAtEofSet(false),
@@ -307,6 +310,7 @@ const char KEY_KEEP_EXTRA_SPACES[] = "Keep Extra Spaces";
 const char KEY_INDENT_PASTED_TEXT[] = "Indent On Text Paste";
 const char KEY_BACKSPACE_INDENTS[] = "Indent On Backspace";
 const char KEY_SHOW_SPACES[] = "Show Spaces";
+const char KEY_MARKER_SIZE[] = "Trailing Marker Size";
 const char KEY_REPLACE_TABS_DYN[] = "ReplaceTabsDyn";
 const char KEY_REMOVE_SPACES[] = "Remove Spaces";
 const char KEY_NEWLINE_AT_EOF[] = "Newline at End of File";
@@ -348,6 +352,7 @@ void KateDocumentConfig::readConfig(const KConfigGroup &config)
     setIndentPastedText(config.readEntry(KEY_INDENT_PASTED_TEXT, false));
     setBackspaceIndents(config.readEntry(KEY_BACKSPACE_INDENTS, true));
     setShowSpaces(config.readEntry(KEY_SHOW_SPACES, false));
+    setMarkerSize(config.readEntry(KEY_MARKER_SIZE, 1));
     setReplaceTabsDyn(config.readEntry(KEY_REPLACE_TABS_DYN, true));
     setRemoveSpaces(config.readEntry(KEY_REMOVE_SPACES, 0));
     setNewLineAtEof(config.readEntry(KEY_NEWLINE_AT_EOF, true));
@@ -398,6 +403,7 @@ void KateDocumentConfig::writeConfig(KConfigGroup &config)
     config.writeEntry(KEY_INDENT_PASTED_TEXT, indentPastedText());
     config.writeEntry(KEY_BACKSPACE_INDENTS, backspaceIndents());
     config.writeEntry(KEY_SHOW_SPACES, showSpaces());
+    config.writeEntry(KEY_MARKER_SIZE, markerSize());
     config.writeEntry(KEY_REPLACE_TABS_DYN, replaceTabsDyn());
     config.writeEntry(KEY_REMOVE_SPACES, removeSpaces());
     config.writeEntry(KEY_NEWLINE_AT_EOF, newLineAtEof());
@@ -752,6 +758,28 @@ bool KateDocumentConfig::showSpaces() const
     return s_global->showSpaces();
 }
 
+void KateDocumentConfig::setMarkerSize(uint markerSize)
+{
+    if (m_markerSize == markerSize) {
+        return;
+    }
+
+    configStart();
+
+    m_markerSize = markerSize;
+
+    configEnd();
+}
+
+uint KateDocumentConfig::markerSize() const
+{
+    if (isGlobal()) {
+        return m_markerSize;
+    }
+
+    return s_global->markerSize();
+}
+
 void KateDocumentConfig::setReplaceTabsDyn(bool on)
 {
     if (m_replaceTabsDynSet && m_replaceTabsDyn == on) {
@@ -1211,12 +1239,14 @@ KateViewConfig::KateViewConfig()
     m_dynWordWrapAlignIndentSet(false),
     m_lineNumbersSet(false),
     m_scrollBarMarksSet(false),
+    m_scrollBarPreviewSet(false),
     m_scrollBarMiniMapSet(false),
     m_scrollBarMiniMapAllSet(false),
     m_scrollBarMiniMapWidthSet(false),
     m_showScrollbarsSet(false),
     m_iconBarSet(false),
     m_foldingBarSet(false),
+    m_foldingPreviewSet(false),
     m_lineModificationSet(false),
     m_bookmarkSortSet(false),
     m_autoCenterLinesSet(false),
@@ -1236,7 +1266,8 @@ KateViewConfig::KateViewConfig()
     m_wordCompletionRemoveTailSet(false),
     m_foldFirstLineSet (false),
     m_autoBracketsSet(false),
-    m_view(0)
+    m_backspaceRemoveComposedSet(false),
+    m_view(nullptr)
 {
     s_global = this;
 
@@ -1255,12 +1286,14 @@ KateViewConfig::KateViewConfig(KTextEditor::ViewPrivate *view)
     m_dynWordWrapAlignIndentSet(false),
     m_lineNumbersSet(false),
     m_scrollBarMarksSet(false),
+    m_scrollBarPreviewSet(false),
     m_scrollBarMiniMapSet(false),
     m_scrollBarMiniMapAllSet(false),
     m_scrollBarMiniMapWidthSet(false),
     m_showScrollbarsSet(false),
     m_iconBarSet(false),
     m_foldingBarSet(false),
+    m_foldingPreviewSet(false),
     m_lineModificationSet(false),
     m_bookmarkSortSet(false),
     m_autoCenterLinesSet(false),
@@ -1278,8 +1311,9 @@ KateViewConfig::KateViewConfig(KTextEditor::ViewPrivate *view)
     m_scrollPastEndSet(false),
     m_allowMarkMenu(true),
     m_wordCompletionRemoveTailSet(false),
-    m_foldFirstLineSet (false),
+    m_foldFirstLineSet(false),
     m_autoBracketsSet(false),
+    m_backspaceRemoveComposedSet(false),
     m_view(view)
 {
 }
@@ -1296,12 +1330,14 @@ const char KEY_DYN_WORD_WRAP_INDICATORS[] = "Dynamic Word Wrap Indicators";
 const char KEY_DYN_WORD_WRAP_ALIGN_INDENT[] = "Dynamic Word Wrap Align Indent";
 const char KEY_LINE_NUMBERS[] = "Line Numbers";
 const char KEY_SCROLL_BAR_MARKS[] = "Scroll Bar Marks";
-const char KEY_SCROLL_BAR_MINI_MAP[] = "Scroll Bar Mini Map";
+const char KEY_SCROLL_BAR_PREVIEW[] = "Scroll Bar Preview";
+const char KEY_SCROLL_BAR_MINI_MAP[] = "Scroll Bar MiniMap";
 const char KEY_SCROLL_BAR_MINI_MAP_ALL[] = "Scroll Bar Mini Map All";
 const char KEY_SCROLL_BAR_MINI_MAP_WIDTH[] = "Scroll Bar Mini Map Width";
 const char KEY_SHOW_SCROLLBARS[] = "Show Scrollbars";
 const char KEY_ICON_BAR[] = "Icon Bar";
 const char KEY_FOLDING_BAR[] = "Folding Bar";
+const char KEY_FOLDING_PREVIEW[] = "Folding Preview";
 const char KEY_LINE_MODIFICATION[] = "Line Modification";
 const char KEY_BOOKMARK_SORT[] = "Bookmark Menu Sorting";
 const char KEY_AUTO_CENTER_LINES[] = "Auto Center Lines";
@@ -1322,6 +1358,7 @@ const char KEY_SCROLL_PAST_END[] = "Scroll Past End";
 const char KEY_FOLD_FIRST_LINE[] = "Fold First Line";
 const char KEY_SHOW_WORD_COUNT[] = "Show Word Count";
 const char KEY_AUTO_BRACKETS[] = "Auto Brackets";
+const char KEY_BACKSPACE_REMOVE_COMPOSED[] = "Backspace Remove Composed Characters";
 }
 
 void KateViewConfig::readConfig(const KConfigGroup &config)
@@ -1333,13 +1370,15 @@ void KateViewConfig::readConfig(const KConfigGroup &config)
     setDynWordWrapIndicators(config.readEntry(KEY_DYN_WORD_WRAP_INDICATORS, 1));
     setDynWordWrapAlignIndent(config.readEntry(KEY_DYN_WORD_WRAP_ALIGN_INDENT, 80));
 
-    setLineNumbers(config.readEntry(KEY_LINE_NUMBERS,  false));
+    setLineNumbers(config.readEntry(KEY_LINE_NUMBERS, false));
 
-    setScrollBarMarks(config.readEntry(KEY_SCROLL_BAR_MARKS,  false));
+    setScrollBarMarks(config.readEntry(KEY_SCROLL_BAR_MARKS, false));
 
-    setScrollBarMiniMap(config.readEntry(KEY_SCROLL_BAR_MINI_MAP,  false));
+    setScrollBarPreview(config.readEntry(KEY_SCROLL_BAR_PREVIEW, true));
 
-    setScrollBarMiniMapAll(config.readEntry(KEY_SCROLL_BAR_MINI_MAP_ALL,  false));
+    setScrollBarMiniMap(config.readEntry(KEY_SCROLL_BAR_MINI_MAP, true));
+
+    setScrollBarMiniMapAll(config.readEntry(KEY_SCROLL_BAR_MINI_MAP_ALL, false));
 
     setScrollBarMiniMapWidth(config.readEntry(KEY_SCROLL_BAR_MINI_MAP_WIDTH,  60));
 
@@ -1349,6 +1388,8 @@ void KateViewConfig::readConfig(const KConfigGroup &config)
 
     setFoldingBar(config.readEntry(KEY_FOLDING_BAR, true));
 
+    setFoldingPreview(config.readEntry(KEY_FOLDING_PREVIEW, true));
+
     setLineModification(config.readEntry(KEY_LINE_MODIFICATION, false));
 
     setBookmarkSort(config.readEntry(KEY_BOOKMARK_SORT, 0));
@@ -1380,6 +1421,8 @@ void KateViewConfig::readConfig(const KConfigGroup &config)
     setShowWordCount(config.readEntry(KEY_SHOW_WORD_COUNT, false));
     setAutoBrackets(config.readEntry(KEY_AUTO_BRACKETS, false));
 
+    setBackspaceRemoveComposed(config.readEntry(KEY_BACKSPACE_REMOVE_COMPOSED, false));
+
     configEnd();
 }
 
@@ -1393,6 +1436,8 @@ void KateViewConfig::writeConfig(KConfigGroup &config)
 
     config.writeEntry(KEY_SCROLL_BAR_MARKS, scrollBarMarks());
 
+    config.writeEntry(KEY_SCROLL_BAR_PREVIEW, scrollBarPreview());
+
     config.writeEntry(KEY_SCROLL_BAR_MINI_MAP, scrollBarMiniMap());
 
     config.writeEntry(KEY_SCROLL_BAR_MINI_MAP_ALL, scrollBarMiniMapAll());
@@ -1405,6 +1450,8 @@ void KateViewConfig::writeConfig(KConfigGroup &config)
 
     config.writeEntry(KEY_FOLDING_BAR, foldingBar());
 
+    config.writeEntry(KEY_FOLDING_PREVIEW, foldingPreview());
+
     config.writeEntry(KEY_LINE_MODIFICATION, lineModification());
 
     config.writeEntry(KEY_BOOKMARK_SORT, bookmarkSort());
@@ -1437,6 +1484,8 @@ void KateViewConfig::writeConfig(KConfigGroup &config)
 
     config.writeEntry(KEY_SHOW_WORD_COUNT, showWordCount());
     config.writeEntry(KEY_AUTO_BRACKETS, autoBrackets());
+
+    config.writeEntry(KEY_BACKSPACE_REMOVE_COMPOSED, backspaceRemoveComposed());
 }
 
 void KateViewConfig::updateConfig()
@@ -1573,6 +1622,29 @@ void KateViewConfig::setScrollBarMarks(bool on)
     configEnd();
 }
 
+bool KateViewConfig::scrollBarPreview() const
+{
+    if (m_scrollBarPreviewSet || isGlobal()) {
+        return m_scrollBarPreview;
+    }
+
+    return s_global->scrollBarPreview();
+}
+
+void KateViewConfig::setScrollBarPreview(bool on)
+{
+    if (m_scrollBarPreviewSet && m_scrollBarPreview == on) {
+        return;
+    }
+
+    configStart();
+
+    m_scrollBarPreviewSet = true;
+    m_scrollBarPreview = on;
+
+    configEnd();
+}
+
 bool KateViewConfig::scrollBarMiniMap() const
 {
     if (m_scrollBarMiniMapSet || isGlobal()) {
@@ -1734,6 +1806,29 @@ void KateViewConfig::setFoldingBar(bool on)
     configEnd();
 }
 
+bool KateViewConfig::foldingPreview() const
+{
+    if (m_foldingPreviewSet || isGlobal()) {
+        return m_foldingPreview;
+    }
+
+    return s_global->foldingPreview();
+}
+
+void KateViewConfig::setFoldingPreview(bool on)
+{
+    if (m_foldingPreviewSet && m_foldingPreview == on) {
+        return;
+    }
+
+    configStart();
+
+    m_foldingPreviewSet = true;
+    m_foldingPreview = on;
+
+    configEnd();
+}
+
 bool KateViewConfig::lineModification() const
 {
     if (m_lineModificationSet || isGlobal()) {
@@ -2149,6 +2244,29 @@ void KateViewConfig::setShowWordCount(bool on)
     configEnd();
 }
 
+bool KateViewConfig::backspaceRemoveComposed() const
+{
+    if (m_backspaceRemoveComposedSet || isGlobal()) {
+        return m_backspaceRemoveComposed;
+    }
+
+    return s_global->backspaceRemoveComposed();
+}
+
+void KateViewConfig::setBackspaceRemoveComposed(bool on)
+{
+    if (m_backspaceRemoveComposedSet && m_backspaceRemoveComposed == on) {
+        return;
+    }
+
+    configStart();
+
+    m_backspaceRemoveComposedSet = true;
+    m_backspaceRemoveComposed = on;
+
+    configEnd();
+}
+
 //END
 
 //BEGIN KateRendererConfig
@@ -2183,7 +2301,7 @@ KateRendererConfig::KateRendererConfig()
       m_searchHighlightColorSet(false),
       m_replaceHighlightColorSet(false),
       m_lineMarkerColorSet(m_lineMarkerColor.size()),
-      m_renderer(0)
+      m_renderer(nullptr)
 {
     // init bitarray
     m_lineMarkerColorSet.fill(true);
