@@ -239,6 +239,9 @@ public:
     void setShowSpaces(bool on);
     bool showSpaces() const;
 
+	void setMarkerSize(uint markerSize);
+	uint markerSize() const;
+
     void setReplaceTabsDyn(bool on);
     bool replaceTabsDyn() const;
 
@@ -359,6 +362,7 @@ private:
     bool m_showTabs : 1;
     bool m_showSpacesSet : 1;
     bool m_showSpaces : 1;
+    uint m_markerSize;
     bool m_replaceTabsDynSet : 1;
     bool m_replaceTabsDyn : 1;
     bool m_removeSpacesSet : 1;
@@ -434,6 +438,10 @@ protected:
     void updateConfig() Q_DECL_OVERRIDE;
 
 public:
+    bool dynWordWrapSet() const
+    {
+        return m_dynWordWrapSet;
+    }
     bool dynWordWrap() const;
     void setDynWordWrap(bool wrap);
 
@@ -449,6 +457,9 @@ public:
     bool scrollBarMarks() const;
     void setScrollBarMarks(bool on);
 
+    bool scrollBarPreview() const;
+    void setScrollBarPreview(bool on);
+
     bool scrollBarMiniMap() const;
     void setScrollBarMiniMap(bool on);
 
@@ -474,6 +485,9 @@ public:
     bool foldingBar() const;
     void setFoldingBar(bool on);
 
+    bool foldingPreview() const;
+    void setFoldingPreview(bool on);
+
     bool lineModification() const;
     void setLineModification(bool on);
 
@@ -558,18 +572,26 @@ public:
     bool showWordCount();
     void setShowWordCount(bool on);
 
+    bool autoBrackets() const;
+    void setAutoBrackets(bool on);
+
+    bool backspaceRemoveComposed() const;
+    void setBackspaceRemoveComposed(bool on);
+
 private:
     bool m_dynWordWrap;
     int m_dynWordWrapIndicators;
     int m_dynWordWrapAlignIndent;
     bool m_lineNumbers;
     bool m_scrollBarMarks;
+    bool m_scrollBarPreview;
     bool m_scrollBarMiniMap;
     bool m_scrollBarMiniMapAll;
     int  m_scrollBarMiniMapWidth;
     int  m_showScrollbars;
     bool m_iconBar;
     bool m_foldingBar;
+    bool m_foldingPreview;
     bool m_lineModification;
     int m_bookmarkSort;
     int m_autoCenterLines;
@@ -589,18 +611,22 @@ private:
     bool m_scrollPastEnd;
     bool m_foldFirstLine;
     bool m_showWordCount;
+    bool m_autoBrackets;
+    bool m_backspaceRemoveComposed;
 
     bool m_dynWordWrapSet : 1;
     bool m_dynWordWrapIndicatorsSet : 1;
     bool m_dynWordWrapAlignIndentSet : 1;
     bool m_lineNumbersSet : 1;
     bool m_scrollBarMarksSet : 1;
+    bool m_scrollBarPreviewSet : 1;
     bool m_scrollBarMiniMapSet : 1;
     bool m_scrollBarMiniMapAllSet : 1;
     bool m_scrollBarMiniMapWidthSet : 1;
     bool m_showScrollbarsSet : 1;
     bool m_iconBarSet : 1;
     bool m_foldingBarSet : 1;
+    bool m_foldingPreviewSet : 1;
     bool m_lineModificationSet : 1;
     bool m_bookmarkSortSet : 1;
     bool m_autoCenterLinesSet : 1;
@@ -619,6 +645,8 @@ private:
     bool m_allowMarkMenu : 1;
     bool m_wordCompletionRemoveTailSet : 1;
     bool m_foldFirstLineSet : 1;
+    bool m_autoBracketsSet : 1;
+    bool m_backspaceRemoveComposedSet : 1;
 
 private:
     static KateViewConfig *s_global;
