@@ -45,6 +45,33 @@
 
 using namespace KTextEditor;
 
+Cursor Cursor::fromString(const QStringRef& str) Q_DECL_NOEXCEPT
+{
+    // parse format "(line, column)"
+    const int startIndex = str.indexOf(QLatin1Char('('));
+    const int endIndex = str.indexOf(QLatin1Char(')'));
+    const int commaIndex = str.indexOf(QLatin1Char(','));
+
+    if (startIndex < 0 || endIndex < 0 || commaIndex < 0 ||
+        commaIndex < startIndex || endIndex < commaIndex ||
+        endIndex < startIndex)
+    {
+        return invalid();
+    }
+
+    bool ok1 = false;
+    bool ok2 = false;
+
+    const int line = str.mid(startIndex + 1, commaIndex - startIndex - 1).toInt(&ok1);
+    const int column = str.mid(commaIndex + 1, endIndex - commaIndex - 1).toInt(&ok2);
+
+    if (!ok1 || !ok2) {
+        return invalid();
+    }
+
+    return {line, column};
+}
+
 Editor::Editor(EditorPrivate *impl)
     : QObject ()
     , d (impl)
@@ -111,7 +138,7 @@ bool View::insertTemplate(const KTextEditor::Cursor& insertPosition,
 
 ConfigPage::ConfigPage(QWidget *parent)
     : QWidget(parent)
-    , d(Q_NULLPTR)
+    , d(nullptr)
 {}
 
 ConfigPage::~ConfigPage()
@@ -137,7 +164,7 @@ View::~View()
 
 Plugin::Plugin(QObject *parent)
     : QObject(parent)
-    , d(Q_NULLPTR)
+    , d(nullptr)
 {}
 
 Plugin::~Plugin()
@@ -150,39 +177,39 @@ int Plugin::configPages() const
 
 ConfigPage *Plugin::configPage(int, QWidget *)
 {
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 MarkInterface::MarkInterface()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {}
 
 MarkInterface::~MarkInterface()
 {}
 
 ModificationInterface::ModificationInterface()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {}
 
 ModificationInterface::~ModificationInterface()
 {}
 
 SessionConfigInterface::SessionConfigInterface()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {}
 
 SessionConfigInterface::~SessionConfigInterface()
 {}
 
 TextHintInterface::TextHintInterface()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {}
 
 TextHintInterface::~TextHintInterface()
 {}
 
 TextHintProvider::TextHintProvider()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {}
 
 TextHintProvider::~TextHintProvider()
@@ -191,7 +218,7 @@ TextHintProvider::~TextHintProvider()
 Command::Command(const QStringList &cmds, QObject *parent)
     : QObject(parent)
     , m_cmds (cmds)
-    , d(Q_NULLPTR)
+    , d(nullptr)
 {
     // register this command
     static_cast<KTextEditor::EditorPrivate *> (KTextEditor::Editor::instance())->cmdManager()->registerCommand (this);
@@ -211,7 +238,7 @@ bool Command::supportsRange(const QString &)
 
 KCompletion *Command::completionObject(KTextEditor::View *, const QString &)
 {
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 bool Command::wantsToProcessText(const QString &)
@@ -222,3 +249,33 @@ bool Command::wantsToProcessText(const QString &)
 void Command::processText(KTextEditor::View *, const QString &)
 {
 }
+
+void View::setScrollPosition(KTextEditor::Cursor &cursor)
+{
+    d->setScrollPositionInternal(cursor);
+}
+
+void View::setHorizontalScrollPosition(int x)
+{
+    d->setHorizontalScrollPositionInternal(x);
+}
+
+KTextEditor::Cursor View::maxScrollPosition() const
+{
+    return d->maxScrollPositionInternal();
+}
+
+int View::firstDisplayedLine(LineType lineType) const
+{
+    return d->firstDisplayedLineInternal(lineType);
+}
+
+int View::lastDisplayedLine(LineType lineType) const
+{
+    return d->lastDisplayedLineInternal(lineType);
+}
+
+QRect View::textAreaRect() const
+{
+    return d->textAreaRectInternal();
+}
