@@ -31,10 +31,13 @@
 #include <ktexteditor/mainwindow.h>
 
 #include <QPointer>
+#include <QScopedPointer>
 #include <QModelIndex>
 #include <QMenu>
 #include <QSpacerItem>
 
+#include <array>
+
 #include "katetextrange.h"
 #include "katetextfolding.h"
 #include "katerenderer.h"
@@ -53,6 +56,7 @@ class KateSpellCheckDialog;
 class KateCompletionWidget;
 class KateViewInternal;
 class KateViewBar;
+class KateTextPreview;
 class KateGotoBar;
 class KateDictionaryBar;
 class KateSpellingMenu;
@@ -62,13 +66,13 @@ class KateStatusBar;
 class KateViewEncodingAction;
 class KateModeMenu;
 class KateAbstractInputMode;
+class KateScriptActionMenu;
+class KateMessageLayout;
 
 class KToggleAction;
 class KSelectAction;
 
 class QAction;
-class QGridLayout;
-class QVBoxLayout;
 
 namespace KTextEditor
 {
@@ -91,9 +95,10 @@ class KTEXTEDITOR_EXPORT ViewPrivate : public KTextEditor::View,
     friend class KTextEditor::View;
     friend class ::KateViewInternal;
     friend class ::KateIconBorder;
+    friend class ::KateTextPreview;
 
 public:
-    ViewPrivate (KTextEditor::DocumentPrivate *doc, QWidget *parent, KTextEditor::MainWindow *mainWindow = Q_NULLPTR);
+    ViewPrivate (KTextEditor::DocumentPrivate *doc, QWidget *parent, KTextEditor::MainWindow *mainWindow = nullptr);
     ~ViewPrivate ();
 
     /**
@@ -118,7 +123,7 @@ public:
     // KTextEditor::ClipboardInterface
     //
 public Q_SLOTS:
-    void paste(const QString *textToPaste = 0);
+    void paste(const QString *textToPaste = nullptr);
     void cut();
     void copy() const;
 
@@ -134,7 +139,7 @@ private Q_SLOTS:
 public:
     void setContextMenu(QMenu *menu) Q_DECL_OVERRIDE;
     QMenu *contextMenu() const Q_DECL_OVERRIDE;
-    QMenu *defaultContextMenu(QMenu *menu = 0L) const Q_DECL_OVERRIDE;
+    QMenu *defaultContextMenu(QMenu *menu = nullptr) const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void aboutToShowContextMenu();
@@ -346,6 +351,7 @@ public:
 Q_SIGNALS:
     void annotationContextMenuAboutToShow(KTextEditor::View *view, QMenu *menu, int line) Q_DECL_OVERRIDE;
     void annotationActivated(KTextEditor::View *view, int line) Q_DECL_OVERRIDE;
+    // KF6: fix View -> KTextEditor::View
     void annotationBorderVisibilityChanged(View *view, bool visible) Q_DECL_OVERRIDE;
 
     void navigateLeft();
@@ -393,6 +399,9 @@ public:
 
     QString currentTextLine();
 
+    QTextLayout * textLayout(int line) const;
+    QTextLayout * textLayout(const KTextEditor::Cursor &pos) const;
+
 public Q_SLOTS:
     void indent();
     void unIndent();
@@ -550,7 +559,7 @@ private Q_SLOTS:
      */
     void slotSelectionChanged();
 
-    void toggleInputMode(bool);
+    void toggleInputMode();
     void cycleInputMode();
 
 public:
@@ -605,11 +614,10 @@ private Q_SLOTS:
     void exportHtmlToClipboard ();
     void exportHtmlToFile ();
 
-public Q_SLOTS: // TODO: turn into good interface, see kte5/foldinginterface.h
+public Q_SLOTS:
     void slotFoldToplevelNodes();
+    void slotExpandToplevelNodes();
     void slotCollapseLocal();
-    void slotCollapseLevel();
-    void slotExpandLevel();
     void slotExpandLocal();
 
 private:
@@ -647,7 +655,7 @@ private:
     QAction *m_selectAll;
     QAction *m_deSelect;
 
-    QList<QAction *> m_inputModeActions;
+    QActionGroup *m_inputModeActions;
 
     KToggleAction *m_toggleBlockSelection;
     KToggleAction *m_toggleInsert;
@@ -867,23 +875,17 @@ public:
     void postMessage(KTextEditor::Message *message, QList<QSharedPointer<QAction> > actions);
 
 private:
-    /** Message widget showing KTextEditor::Messages above the View. */
-    KateMessageWidget *m_topMessageWidget;
-    /** Message widget showing KTextEditor::Messages below the View. */
-    KateMessageWidget *m_bottomMessageWidget;
-    /** Message widget showing KTextEditor::Messages as view overlay in top right corner. */
-    KateMessageWidget *m_floatTopMessageWidget;
-    /** Message widget showing KTextEditor::Messages as view overlay in bottom left corner. */
-    KateMessageWidget *m_floatBottomMessageWidget;
+    /**
+     * Message widgets showing KTextEditor::Messages.
+     * The index of the array maps to the enum KTextEditor::Message::MessagePosition.
+     */
+    std::array<KateMessageWidget *, 5> m_messageWidgets{{nullptr}};
     /** Layout for floating notifications */
-    QVBoxLayout *m_notificationLayout;
+    KateMessageLayout *m_notificationLayout = nullptr;
 
     // for unit test 'tests/messagetest.cpp'
 public:
-    KateMessageWidget *messageWidget()
-    {
-        return m_floatTopMessageWidget;
-    }
+    KateMessageWidget *messageWidget();
 
 private:
     /**
@@ -966,6 +968,27 @@ private:
     // remember folding state to prevent refolding the first line if it was manually unfolded,
     // e.g. when saving a file or changing other config vars
     bool m_autoFoldedFirstLine;
+
+public:
+    void setScrollPositionInternal(KTextEditor::Cursor &cursor);
+
+    void setHorizontalScrollPositionInternal(int x);
+
+    KTextEditor::Cursor maxScrollPositionInternal() const;
+
+    int firstDisplayedLineInternal(LineType lineType) const;
+
+    int lastDisplayedLineInternal(LineType lineType) const;
+
+    QRect textAreaRectInternal() const;
+
+private:
+    /**
+     * script action menu, stored in scoped pointer to ensure
+     * destruction before other QObject auto-cleanup as it
+     * manage sub objects on its own that have this view as parent
+     */
+    QScopedPointer<KateScriptActionMenu> m_scriptActionMenu;
 };
 
 }
