@@ -189,7 +189,7 @@ KTextEditor::Cursor ModeBase::findNextWordStart(int fromLine, int fromColumn, bo
     QString line = getLine(fromLine);
 
     // the start of word pattern need to take m_extraWordCharacters into account if defined
-    QString startOfWordPattern = QString::fromLatin1("\\b(\\w");
+    QString startOfWordPattern = QStringLiteral("\\b(\\w");
     if (m_extraWordCharacters.length() > 0) {
         startOfWordPattern.append(QLatin1String("|[") + m_extraWordCharacters + QLatin1Char(']'));
     }
@@ -293,7 +293,7 @@ KTextEditor::Cursor ModeBase::findPrevWordEnd(int fromLine, int fromColumn, bool
 {
     QString line = getLine(fromLine);
 
-    QString endOfWordPattern = QString::fromLatin1("\\S\\s|\\S$|\\w\\W|\\S\\b|^$");
+    QString endOfWordPattern = QStringLiteral("\\S\\s|\\S$|\\w\\W|\\S\\b|^$");
 
     if (m_extraWordCharacters.length() > 0) {
         endOfWordPattern.append(QLatin1String("|[") + m_extraWordCharacters + QLatin1String("][^") + m_extraWordCharacters + QLatin1Char(']'));
@@ -371,7 +371,7 @@ KTextEditor::Cursor ModeBase::findPrevWordStart(int fromLine, int fromColumn, bo
     QString line = getLine(fromLine);
 
     // the start of word pattern need to take m_extraWordCharacters into account if defined
-    QString startOfWordPattern = QString::fromLatin1("\\b(\\w");
+    QString startOfWordPattern = QStringLiteral("\\b(\\w");
     if (m_extraWordCharacters.length() > 0) {
         startOfWordPattern.append(QLatin1String("|[") + m_extraWordCharacters + QLatin1Char(']'));
     }
@@ -486,7 +486,7 @@ KTextEditor::Cursor ModeBase::findWordEnd(int fromLine, int fromColumn, bool onl
 {
     QString line = getLine(fromLine);
 
-    QString endOfWordPattern = QString::fromLatin1("\\S\\s|\\S$|\\w\\W|\\S\\b");
+    QString endOfWordPattern = QStringLiteral("\\S\\s|\\S$|\\w\\W|\\S\\b");
 
     if (m_extraWordCharacters.length() > 0) {
         endOfWordPattern.append(QLatin1String("|[") + m_extraWordCharacters + QLatin1String("][^") + m_extraWordCharacters + QLatin1Char(']'));
@@ -1207,9 +1207,9 @@ void ModeBase::addToNumberUnderCursor(int count)
 
     QString basePrefix;
     if (base == 16) {
-        basePrefix = QLatin1String("0x");
+        basePrefix = QStringLiteral("0x");
     } else if (base == 8) {
-        basePrefix = QLatin1String("0");
+        basePrefix = QStringLiteral("0");
     }
     const QString withoutBase = numberAsString.mid(basePrefix.length());
 
@@ -1218,8 +1218,8 @@ void ModeBase::addToNumberUnderCursor(int count)
     // Create the new text string to be inserted. Prepend with “0x” if in base 16, and "0" if base 8.
     // For non-decimal numbers, try to keep the length of the number the same (including leading 0's).
     const QString newNumberPadded = (base == 10) ?
-                                    QString::fromLatin1("%1").arg(newNumber, 0, base) :
-                                    QString::fromLatin1("%1").arg(newNumber, withoutBase.length(), base, QLatin1Char('0'));
+                                    QStringLiteral("%1").arg(newNumber, 0, base) :
+                                    QStringLiteral("%1").arg(newNumber, withoutBase.length(), base, QLatin1Char('0'));
     const QString newNumberText = basePrefix + newNumberPadded;
 
     // Replace the old number string with the new.
@@ -1245,10 +1245,12 @@ void ModeBase::switchView(Direction direction)
     int curr_x2 = current_point.x() + m_view->width();
     int curr_y1 = current_point.y();
     int curr_y2 = current_point.y() + m_view->height();
-    int curr_cursor_y = m_view->mapToGlobal(m_view->cursorToCoordinate(m_view->cursorPosition())).y();
-    int curr_cursor_x = m_view->mapToGlobal(m_view->cursorToCoordinate(m_view->cursorPosition())).x();
+    const KTextEditor::Cursor cursorPos = m_view->cursorPosition();
+    const QPoint globalPos = m_view->mapToGlobal(m_view->cursorToCoordinate(cursorPos));
+    int curr_cursor_y = globalPos.y();
+    int curr_cursor_x = globalPos.x();
 
-    KTextEditor::ViewPrivate *bestview = NULL;
+    KTextEditor::ViewPrivate *bestview = nullptr;
     int  best_x1 = -1, best_x2 = -1, best_y1 = -1, best_y2 = -1, best_center_y = -1, best_center_x = -1;
 
     if (direction == Next && visible_views.count() != 1) {
@@ -1276,7 +1278,7 @@ void ModeBase::switchView(Direction direction)
                 if (view != m_view && x2 <= curr_x1 &&
                         (x2 > best_x2 ||
                          (x2 == best_x2 && qAbs(curr_cursor_y - center_y) < qAbs(curr_cursor_y - best_center_y)) ||
-                         bestview == NULL)) {
+                         bestview == nullptr)) {
                     bestview = view;
                     best_x2 = x2;
                     best_center_y = center_y;
@@ -1286,7 +1288,7 @@ void ModeBase::switchView(Direction direction)
                 if (view != m_view && x1 >= curr_x2 &&
                         (x1 < best_x1 ||
                          (x1 == best_x1 && qAbs(curr_cursor_y - center_y) < qAbs(curr_cursor_y - best_center_y)) ||
-                         bestview == NULL)) {
+                         bestview == nullptr)) {
                     bestview = view;
                     best_x1 = x1;
                     best_center_y = center_y;
@@ -1296,16 +1298,17 @@ void ModeBase::switchView(Direction direction)
                 if (view != m_view && y1 >= curr_y2 &&
                         (y1 < best_y1 ||
                          (y1 == best_y1 && qAbs(curr_cursor_x - center_x) < qAbs(curr_cursor_x - best_center_x)) ||
-                         bestview == NULL)) {
+                         bestview == nullptr)) {
                     bestview = view;
                     best_y1 = y1;
                     best_center_x = center_x;
                 }
+                break;
             case Up:
                 if (view != m_view && y2 <= curr_y1 &&
                         (y2 > best_y2 ||
                          (y2 == best_y2 && qAbs(curr_cursor_x - center_x) < qAbs(curr_cursor_x - best_center_x)) ||
-                         bestview == NULL)) {
+                         bestview == nullptr)) {
                     bestview = view;
                     best_y2 = y2;
                     best_center_x = center_x;
@@ -1317,7 +1320,7 @@ void ModeBase::switchView(Direction direction)
 
         }
     }
-    if (bestview != NULL) {
+    if (bestview != nullptr) {
         bestview->setFocus();
         bestview->setInputMode(KTextEditor::View::ViInputMode);
     }
